@@ -29,6 +29,10 @@ DEFAULT_NA_VALUES = ',#N/A,N/A,#N/A N/A,n/a,NA,<NA>,#NA,NULL,null,NaN,nan'
 DEFAULT_ONLY_PRINTABLE_CHARACTERS = 'no'
 DEFAULT_MATERIALIZE_DEFAULT_GRAPH = 'no'
 
+# ORACLE
+DEFAULT_ORACLE_CLIENT_LIB_DIR = ''
+DEFAULT_ORACLE_CLIENT_CONFIG_DIR = ''
+
 # DEVELOPMENT OPTIONS
 DEFAULT_PUSH_DOWN_SQL_DISTINCTS = 'no'
 DEFAULT_PUSH_DOWN_SQL_JOINS = 'no'
