@@ -17,15 +17,16 @@ from ..constants import *
 from ..utils import replace_predicates_in_graph, get_repeated_elements_in_list
 from ..mapping.mapping_constants import MAPPINGS_DATAFRAME_COLUMNS, MAPPING_PARSING_QUERY, JOIN_CONDITION_PARSING_QUERY
 from ..mapping.mapping_partitioner import MappingPartitioner
-from ..data_source.relational_source import get_column_datatype
+from ..data_source.relational_database import get_column_datatype
 
 
 def _mapping_to_rml(mapping_graph):
     """
-    Replaces R2RML rules in in the graph with the corresponding RML rules.
+    Replaces R2RML rules in the graph with the corresponding RML rules.
     """
 
-    # add RML and QL namespaces
+    # add namespaces
+    mapping_graph.bind('rr', rdflib.term.URIRef(RML_NAMESPACE))
     mapping_graph.bind('rml', rdflib.term.URIRef(RML_NAMESPACE))
     mapping_graph.bind('ql', rdflib.term.URIRef(QL_NAMESPACE))
 
